@@ -9,11 +9,12 @@ utaupy.ust.Ust をもとに、ファイル入出力機能を変更したもの
 from copy import deepcopy
 # from pprint import pprint
 from sys import argv
+from typing import Callable
 
 from utaupy import ust as _ust
 
 
-def run(your_function, option=None, path=None):
+def run(your_function: Callable, option=None, path=None):
     """
     UTAUプラグインスクリプトファイルの入出力をする。
     your_function: 実行したい関数
@@ -33,7 +34,7 @@ def run(your_function, option=None, path=None):
     plugin.write(path)
 
 
-def load(path: str, encoding='shift-jis'):
+def load(path: str, encoding='cp932'):
     """
     UTAUプラグイン一時ファイルを読み取る
     USTのやつを一部改変
@@ -49,12 +50,13 @@ class UtauPlugin(_ust.Ust):
     UTAUプラグインの一時ファイル用のクラス
     UST用のクラスを継承
     """
+
     def __init__(self):
         super().__init__()
         # プラグインのときは[#TRACKEND]が不要
         self.trackend = None
 
-    def write(self, path: str, mode: str = 'w', encoding: str = 'shift-jis') -> str:
+    def write(self, path: str, mode: str = 'w', encoding: str = 'cp932') -> str:
         """
         USTをファイル出力
         """
@@ -64,3 +66,17 @@ class UtauPlugin(_ust.Ust):
         with open(path, mode=mode, encoding=encoding) as f:
             f.write(s)
         return s
+
+    def as_ust(self) -> _ust.Ust:
+        """
+        utaupy.ust.Ustオブジェクトに変換する。
+        USTファイルとして保存するときに使う。
+        """
+        plugin = deepcopy(self)
+        # Ustオブジェクトを生成
+        ust = _ust.Ust()
+        # [#SETTING] の情報をコピー
+        ust.version = plugin.version   # [#VERSION]
+        ust.setting = plugin.setting  # [#SETTING]
+        ust.notes = plugin.notes  # [#1234], [#INSERT], [#DELETE]
+        return ust
